package com.nemrodsoftware;

import java.io.File;
import java.io.IOException;
import java.util.List;

import com.nemrodsoftware.model.Locale;
import com.nemrodsoftware.model.Module;
import com.nemrodsoftware.model.Project;

public interface INemrodClient
{

    public abstract void create(Project project); 
    
    public abstract void delete(String projectName); 
    
    public abstract void setVisibility(String projectName,Boolean isPublic) ;
    
    public abstract void setNbMaxUser(String projectName, Long nbMaxUser);
    
    public abstract void setNbMaxLocale(String projectName, Long nbMaxLocale); 
    
    public abstract void setNbMaxMessage(String projectName,Long nbMaxMessage) ;
    
    public abstract Long getNbMaxMessage(String projectName); 

    public abstract Long getNbMaxLocale(String projectName);

    public abstract Long getNbMaxUser(String projectName); 

    public abstract void addMember(String projectName, String login); 
    
    /**
     * @param project
     * @return the list of all locales available for this project
     */
    public abstract List<Locale> listLocale(String project);

    /**
     * @param project
     * @return the list of modules for this project
     */
    public abstract List<Module> listModule(String project);

    /**
     * @param project
     * @param moduleName
     * @param modulePath
     * @return the module with the given name or null if not found 
     */
    public abstract Module findModule(String project, String moduleName, String modulePath);

    /**
     * @param project
     * @param localeName
     * @param module
     * @param exportType
     * @param exportEmptyValues
     * @param exportOnlyApprovedValues
     * @param workFolder
     * @return a file descriptor on the downloaded file
     * @throws IOException if an error occured when downloading the file
     */
    public abstract File export(String project, String localeName, Module module, String exportType, boolean exportEmptyValues, boolean exportOnlyApprovedValues, String workFolder) throws IOException;

    /**
     * @param project
     * @param format
     * @param module
     * @param modulePath
     * @param masterFile
     */
    public abstract void sync(String project, String format, Module module, File masterFile);

}